#! python

# #####################################################################
# Copyright (c) 2017, NMSU Board of Regeants
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
# 
# 1. Redistributions of source code must retain the above copyright 
#    notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright 
#    notice, this list of conditions and the following disclaimer in 
#    the documentation and/or other materials provided with the 
#    distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY 
# WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.
# #####################################################################

# Standard library imports.
import argparse
import copy
import httplib
import sys
import urllib


# The version number of this module/script.
__version__ = '1.0'


# These attributes describe the web application that provides the NDFD 
# XML files.
HOST = 'forecast.weather.gov'
APP = '/MapClick.php'

# These attributes describe the parameters and the header sent to the 
# National Weather service server.
PARAMS = {'FcstType': 'digitalDWML', 'lat': '32.282', 'lon': '-106.757'}
HEADERS = {'User-Agent': 'Python/2.x'}


def run(latitude, longitude):

    params = copy.deepcopy(PARAMS)

    params['lat'] = str(latitude)
    params['lon'] = str(longitude)
    url = '%s?%s' % (APP, urllib.urlencode(params))

    xml = None

    try:

        conn = httplib.HTTPConnection(HOST)
        conn.request('GET', url, headers = HEADERS)
        response = conn.getresponse()
        xml = response.read()
        conn.close()

    except Exception as e:

        sys.stderr.write('Error: %s\n' % str(e))
        xml = None

    return xml


if __name__ == '__main__':

    parser = argparse.ArgumentParser()
    parser.add_argument('latitude', 
        type = float, 
        help = 'The latitude component of a point forecast data request.')
    parser.add_argument('longitude', 
        type = float, 
        help = 'The longitude component of a point forecast data request.')

    # Parse the command line arguments.
    args = parser.parse_args()

    xml = run(args.latitude, args.longitude)

    if xml is not None:
        sys.stdout.write(xml + '\n')

    # Explicitly exit the script.
    sys.exit(0)



